#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.19
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import inquirer from 'inquirer';
import getProperty from 'js-cool/es/getProperty';
import getCurrentBranch from '@gitmars/core/lib/git/getCurrentBranch';
import { createArgs } from '@gitmars/core/lib/utils/command';
import * as commands from '#lib/go/index';
import goConfig from '#lib/conf/go';
import i18n from '#lib/locales/index';

const { green, red } = chalk;
const { args, options } = goConfig;
program.name("gitm go").usage("[command]").description(
  i18n.__("Intelligent guessing of the action you want to perform")
);
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (command) => {
  const current = getCurrentBranch();
  sh.echo(
    green(
      i18n.__(
        "Current branch is {{{current}}}, I suspect you may want to do the following: ",
        { current }
      )
    )
  );
  if (command) {
    const cmd = getProperty(commands, command);
    if (!cmd) {
      sh.echo(
        red(
          i18n.__(
            "The command you entered was not found and may not be supported at this time"
          )
        )
      );
      process.exit(1);
    }
    cmd();
  } else {
    inquirer.prompt({
      type: "list",
      name: "command",
      message: i18n.__("Please select the operation you want?"),
      default: "combine",
      choices: [
        new inquirer.Separator(
          " === 1. " + i18n.__("Gitmars Workflow") + " === "
        ),
        "combine",
        "end",
        "update",
        "build",
        "start",
        "undo",
        "redo",
        "admin.publish",
        "admin.update",
        "admin.create",
        "admin.clean",
        new inquirer.Separator(
          " === 2. " + i18n.__("Advanced Tools") + " === "
        ),
        "branch",
        "copy",
        "get",
        "save",
        "cleanbranch",
        "clean",
        "revert",
        "link",
        "unlink",
        "postmsg",
        new inquirer.Separator(" === " + i18n.__("Exit") + " === "),
        "exit",
        new inquirer.Separator()
      ],
      filter: (val) => {
        return val;
      }
    }).then((answers) => {
      if (answers.command === "exit") {
        sh.echo(green(i18n.__("exited")));
        process.exit(0);
      }
      sh.echo(
        green(
          i18n.__(
            "You have selected the {{{something}}} command",
            {
              something: answers.command
            }
          )
        )
      );
      getProperty(commands, answers.command)();
    });
  }
});
program.parse(process.argv);
